<?php
/**
 * Plugin Name: Bulk Edit Upsells and Cross-Sells for WooCommerce
 * Description: Bulk Edit Upsells and Cross-sells for WooCommerce is a fast and easy way to set or update upsells and cross-sells for products in your WooCommerce catalog.
 * Author URI:  https://www.saffiretech.com
 * Author:      SaffireTech
 * Text Domain: bulk-edit-upsells-and-cross-sells-for-woocommerce
 * Domain Path: /languages
 * Stable Tag : 2.0.3
 * Requires at least: 5.0
 * Tested up to: 6.1.1
 * Requires PHP: 7.2
 * WC requires at least: 4.0.0
 * WC tested up to: 7.2.2
 * License:     GPLv3
 * License URI: URI: https://www.gnu.org/licenses/gpl-3.0.html
 * Version:     2.0.3
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

define( 'BUCW_BULK_EDIT_PLUGIN_BASENAME', plugin_basename( __FILE__ ) );
/**
 * This function includes all required file.
 *
 * @return void
 */
function beucw_upsells_crosssells_include_file() {
	if ( ! function_exists( 'is_plugin_active' ) ) {
		include_once ABSPATH . 'wp-admin/includes/plugin.php';
	}

	if ( ( file_exists( WP_PLUGIN_DIR . '/woocommerce/woocommerce.php' ) ) && is_plugin_active( 'woocommerce/woocommerce.php' ) ) {
		require_once plugin_dir_path( __FILE__ ) . 'includes/beucw-settings.php';
		require_once plugin_dir_path( __FILE__ ) . 'includes/beucw-functions.php';
	}
}

add_action( 'init', 'beucw_upsells_crosssells_include_file' );

/**
 * Function enqueue different library.
 *
 * @param string $hook .
 * @return void
 */
function beucw_upsells_assets( $hook ) {
	if ( 'product_page_bulk-edit-upsells-crosssells' === $hook ) {
		wp_enqueue_script( 'jquery' );
		wp_enqueue_style( 'bucw_upsells_css', plugins_url( 'assets/css/beucw-bulk-upsells-crosssells.css', __FILE__ ), array(), '2.0.2' );
		wp_enqueue_style( 'bucw_sweetalert2_css', plugins_url( 'assets/css/sweetalert2.min.css', __FILE__ ), array(), '10.10.1' );
		wp_enqueue_style( 'bucw_select2', plugins_url( 'assets/css/select2.min.css', __FILE__ ), array(), '10.10.1' );
		wp_enqueue_script( 'bucw_sweetalert2_js', plugins_url( 'assets/js/sweetalert2.all.min.js', __FILE__ ), array(), '10.10.1', false );
		wp_enqueue_script( 'bucw_select2', plugins_url( 'assets/js/select2.min.js', __FILE__ ), array(), '0.10.0', false );
		wp_register_script( 'bucw_upsells_js', plugins_url( 'assets/js/beucw-bulk-upsells-crosssells.js', __FILE__ ), array( 'jquery', 'jquery-ui-autocomplete' ), '2.0.2', true );
		wp_enqueue_script( 'bucw_upsells_js' );

		wp_localize_script(
			'bucw_upsells_js',
			'upsellajaxapi',
			array(
				'url'   => admin_url( 'admin-ajax.php' ),
				'nonce' => wp_create_nonce( 'bulk-edit-upsells-and-cross-sells-for-woocommerce' ),
			)
		);
		wp_set_script_translations( 'bucw_upsells_js', 'bulk-edit-upsells-and-cross-sells-for-woocommerce', plugin_dir_path( __FILE__ ) . 'languages/' );
	}
}
add_action( 'admin_enqueue_scripts', 'beucw_upsells_assets' );

/**
 * To load text domain files.
 *
 * @return void
 */
function beucw_load_plugin_textdomain_file() {
	load_plugin_textdomain( 'bulk-edit-upsells-and-cross-sells-for-woocommerce', false, basename( dirname( __FILE__ ) ) . '/languages/' );
}
add_action( 'admin_init', 'beucw_load_plugin_textdomain_file' );
